@@ -12,8 +12,7 @@
 import re
 from urllib import urlopen
 import screenlets
-from screenlets.options import StringOption, BoolOption
-from Numeric import *
+from screenlets.options import StringOption, BoolOption, ColorOption, FontOption
 import pygtk
 pygtk.require('2.0')
 import cairo
@@ -25,16 +24,18 @@ import datetime
 import math
 import gtk
 from gtk import gdk
-
+import os
+from screenlets import Plugins
+proxy = Plugins.importAPI('Proxy')
 
 class ClearWeatherScreenlet(screenlets.Screenlet):
 	"""A Weather Screenlet modified from the original to look more clear and to enable the use of icon pack , you can use any icon pack compatible with weather.com , you can find many packs on deviantart.com or http://liquidweather.net/icons.php#iconsets."""
 	
 	# default meta-info for Screenlets
 	__name__ = 'ClearWeatherScreenlet'
-	__version__ = '0.3'
-	__author__ = 'by Helder Fraga aka Whise based on Weather Screenlet by robgig1088'
-	__desc__ = 'A Weather Screenlet modified from the original to look more clear and to enable the use of icon pack , you can use any icon pack compatible with weather.com , you can find many packs on deviantart.com or http://liquidweather.net/icons.php#iconsets.'
+	__version__ = '0.5'
+	__author__ = 'by Helder Fraga aka Whise'
+	__desc__ = 'A Weather Screenlet modified from the original to look more clear and to enable the use of icon pack , you can use any icon pack compatible with weather.com , you can find many packs on deviantart.com or http://liquidweather.net/icons.php#iconsets.Weather information provided by www.weather.com'
 
 	# internals
 	__timeout = None
@@ -46,11 +47,13 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 	lastx = 0   ## the cursor position inside the window (is there a better way to do this??)
 	over_button = 1
 
-	ZIP = "USNY0996"
+	ZIP = "POXX0079"
 	use_metric = True
 	show_daytemp = True
 	mini = False
-	
+	font = 'Sans'
+	font_color = (1,1,1, 0.8)
+	background_color = (0,0,0, 0.8)
 	latest = []          ## the most recent settings we could get...
 	latestHourly = []
 
@@ -76,7 +79,7 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 			bool(self.show_error_message), 'Show error messages', 
 			'Show an error message on invalid location code'))
 		self.add_option(BoolOption('Weather', 'use_metric', 
-			bool(self.use_metric), 'Use metric over imperial units', 
+			bool(self.use_metric), 'Use celsius temperature ', 
 			'Use the metric system for measuring values'))
 		self.add_option(BoolOption('Weather', 'mini',
 			bool(self.mini), 'Use mini-mode',
@@ -84,7 +87,13 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 		self.add_option(BoolOption('Weather', 'show_daytemp',
 			bool(self.show_daytemp), 'Show 6 day temperature',
 			'Show 6 day temperature high/low'))
-
+		self.add_option(FontOption('Weather','font', 
+			self.font, 'Font', 
+			'font'))
+		self.add_option(ColorOption('Weather','font_color', 
+			self.font_color, 'Text color', 'font_color'))
+		self.add_option(ColorOption('Weather','background_color', 
+			self.background_color, 'Back color(only with default theme)', 'only works with default theme'))
 	
 	# attribute-"setter", handles setting of attributes
 	def __setattr__(self, name, value):
@@ -119,7 +128,7 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 		temp = self.parseWeatherData()
 		temp2 = self.parseWeatherDataHourly()
 		
-		if temp[0]["where"] == '':    ##did we get any data?  if not...
+		if len(temp) == 0 or temp[0]["where"]  == '':    ##did we get any data?  if not...
 			if self.show_error_message==1 and self.updated_recently == 1:
 				self.show_error()
 			self.updated_recently = 0
@@ -137,19 +146,26 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 			unit = 'm'
 		else:
 			unit = 's'
-		data = urlopen('http://xoap.weather.com/weather/local/'+self.ZIP+'?cc=*&dayf=10&prod=xoap&par=1003666583&key=4128909340a9b2fc&unit='+unit).read()
+
 		forecast = []
 
-		dcstart = data.find('<loc ')
-		dcstop = data.find('</cc>')     ###### current conditions
-		data_current = data[dcstart:dcstop]
-		forecast.append(self.tokenizeCurrent(data_current))
+		
+		proxies = proxy.Proxy().get_proxy()
+		try:
+			data = urlopen('http://xoap.weather.com/weather/local/'+self.ZIP+'?cc=*&dayf=10&prod=xoap&par=1003666583&key=4128909340a9b2fc&unit='+unit + '&link=xoap',proxies=proxies).read()
 
-		for x in range(10):
-			dcstart = data.find('<day d=\"'+str(x))
-			dcstop = data.find('</day>',dcstart)   #####10-day forecast
-			day = data[dcstart:dcstop]
-			forecast.append(self.tokenizeForecast(day))
+			dcstart = data.find('<loc ')
+			dcstop = data.find('</cc>')     ###### current conditions
+			data_current = data[dcstart:dcstop]
+			forecast.append(self.tokenizeCurrent(data_current))
+
+			for x in range(10):
+				dcstart = data.find('<day d=\"'+str(x))
+				dcstop = data.find('</day>',dcstart)   #####10-day forecast
+				day = data[dcstart:dcstop]
+				forecast.append(self.tokenizeForecast(day))
+		except:
+			pass
 
 		return forecast
 
@@ -159,14 +175,19 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 			unit = 'm'
 		else:
 			unit = 's'
-		data = urlopen('http://xoap.weather.com/weather/local/'+self.ZIP+'?cc=*&dayf=10&prod=xoap&par=1003666583&key=4128909340a9b2fc&unit='+unit+'&hbhf=12').read()
-		hforecast = []
 
-		for x in range(8):
-			dcstart = data.find('<hour h=\"'+str(x))
-			dcstop = data.find('</hour>',dcstart)   ####hourly forecast
-			hour = data[dcstart:dcstop]
-			hforecast.append(self.tokenizeForecastHourly(hour))
+		hforecast = []
+		try:
+			
+			proxies = proxy.Proxy().get_proxy()
+			data = urlopen('http://xoap.weather.com/weather/local/'+self.ZIP+'?cc=*&dayf=10&prod=xoap&par=1003666583&key=4128909340a9b2fc&unit='+unit+'&hbhf=12&link=xoap',proxies=proxies).read()
+			for x in range(8):
+				dcstart = data.find('<hour h=\"'+str(x))
+				dcstop = data.find('</hour>',dcstart)   ####hourly forecast
+				hour = data[dcstart:dcstop]
+				hforecast.append(self.tokenizeForecastHourly(hour))
+		except IOError, e:
+			print "Error retrieving weather data", e
 
 		return hforecast
 
@@ -305,35 +326,30 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 		ctx.scale(self.scale, self.scale)
 		# draw bg (if theme available)
 		ctx.set_operator(cairo.OPERATOR_OVER)
+		ctx.set_source_rgba(*self.background_color)
 		if self.theme:
+			s = self.theme.path
 			if (self.mini == False and weather != []):
-				self.theme['weather-bg.svg'].render_cairo(ctx)
+				self.theme.render(ctx,'weather-bg')
+				
+				if self.theme_name == 'default':self.draw_rounded_rectangle(ctx,11.5,18.5,8,120,80)
+				self.theme.render(ctx,'weather-bg')
 			else:
-				self.theme['weather-bg-mini.svg'].render_cairo(ctx)
+				if self.theme_name == 'default':self.draw_rounded_rectangle(ctx,11.5,18.5,8,120,41.8)
+				self.theme.render(ctx,'weather-bg-mini')
+				
+		ctx.set_source_rgba(*self.font_color)
 		# draw memory-graph
 		if self.theme:
-			if (self.theme_name == "glassy"):
-				ctx.set_source_rgba(0, 0, 0, 0.8)
-			else:
-				ctx.set_source_rgba(1, 1, 1, 0.8)
-
 			if weather == []:
-				ctx.save()	
-				ctx.translate(15, 35)
-				p_layout = ctx.create_layout()
-				p_fdesc = pango.FontDescription()
-				p_fdesc.set_family_static("Sans")
-				p_fdesc.set_size(4 * pango.SCALE)
-				p_fdesc.set_weight(300)
-				p_fdesc.set_style(pango.STYLE_NORMAL)   ####render no info message
-				p_layout.set_font_description(p_fdesc)
-				p_layout.set_markup('<b>No weather information available</b>')						
-				ctx.show_layout(p_layout)
-				ctx.restore()
+				
+				self.draw_text(ctx,'<b>No weather information available</b>', 15, 35, self.font.split(' ')[0], 4,  self.width,pango.ALIGN_LEFT)
+
 			else:
 				ctx.save()
 				ctx.translate(-2, 0)
 				ctx.scale(.6,.6)
+				if weather[0]["icon"]=="-": weather[0]["icon"]="48"
 				icon = str(self.get_icon(int(weather[0]["icon"])) )
 				self.theme.render(ctx,icon)
 				ctx.restore()
@@ -346,39 +362,13 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 			#		self.theme.render(ctx,icon)
 			#		ctx.restore()
 
-				ctx.save()
-				ctx.translate(90,25)
 				degree = unichr(176)
-				p_layout = ctx.create_layout()
-				p_fdesc = pango.FontDescription()
-				p_fdesc.set_family_static("Sans")
-				p_fdesc.set_size(14 * pango.SCALE)
-				p_fdesc.set_weight(300)
-				p_fdesc.set_style(pango.STYLE_NORMAL)
-				p_layout.set_font_description(p_fdesc)   ######render current temp
 				if len(str(weather[0]["temp"])) == 3:
 					ctx.translate(-7, 0)
-				p_layout.set_markup('<b>' + weather[0]["temp"] + degree +'</b>')							
-				ctx.show_layout(p_layout)
-				ctx.restore()
+				self.draw_text(ctx,'<b>' + weather[0]["temp"] + degree +'</b>', 90,25, self.font.split(' ')[0], 14,  self.width,pango.ALIGN_LEFT)
 
-				ctx.save()	
-				ctx.translate(25  , 50)
-				p_layout1 = ctx.create_layout()
-				p_fdesc = pango.FontDescription()
-				p_fdesc.set_family_static("Sans")
-				p_fdesc.set_size(6 * pango.SCALE)
-			
-			
+				self.draw_text(ctx,'<b>' + weather[0]["where"][:weather[0]["where"].find(',')][:10] +'</b>', -5,50, self.font.split(' ')[0], 6, self.width,pango.ALIGN_RIGHT)
 
-				p_layout1.set_font_description(p_fdesc)      ### draw location
-
-			
-				p_layout1.set_width(int((102* pango.SCALE )))
-				p_layout1.set_alignment(pango.ALIGN_RIGHT)
-				p_layout1.set_markup('<b>' + weather[0]["where"][:weather[0]["where"].find(',')][:10] +'</b>')
-
-				ctx.show_layout(p_layout1)
 			#	ctx.translate(0, 6)
 			#	p_layout = ctx.create_layout()
 			#	p_fdesc.set_size(3 * pango.SCALE)
@@ -396,7 +386,7 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 			#	p_layout.set_font_description(p_fdesc)
 			#	p_layout.set_markup('<b>' + "High: "+weather[1]["high"] + degree + "   Low: " +weather[1]["low"] + degree +'</b>')						
 			#	ctx.show_layout(p_layout)
-				ctx.restore()	
+					
 
 
 #other stuff text
@@ -420,38 +410,33 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 		#		ctx.translate(0, 5)
 		#		p_layout.set_markup("p:<b>"+weather[0]["pressure"]+"</b>  h:<b>"+weather[0]["humid"] + "%</b>  w:<b>" +weather[0]["windspeed"] + " m/s</b>")	
 		#		ctx.show_layout(p_layout)
-				ctx.save() 
-				ctx.restore()
-				
 
 				if (self.mini == False):
+			
 					ctx.save() 
-					ctx.translate(14, 65)
-					self.theme['day-bg.svg'].render_cairo(ctx)   ###render the days background
-					p_layout = ctx.create_layout()
-					p_fdesc = pango.FontDescription()
-					p_fdesc.set_family_static("Monospace")
-					p_fdesc.set_size(6 * pango.SCALE)
-					p_fdesc.set_weight(300)    ##### render the days of the week
-					p_fdesc.set_style(pango.STYLE_NORMAL)
-					p_layout.set_font_description(p_fdesc)
-					p_layout.set_markup('<b>' +weather[1]["day"][:3] + '</b>')						
-					ctx.show_layout(p_layout)
-					ctx.translate(20, 0)
-					p_layout.set_markup('<b>' +weather[2]["day"][:3] + '</b>')	
-					ctx.show_layout(p_layout)
-					ctx.translate(20, 0)
-					p_layout.set_markup('<b>' +weather[3]["day"][:3] + '</b>')	
-					ctx.show_layout(p_layout)
-					ctx.translate(20, 0)
-					p_layout.set_markup('<b>' +weather[4]["day"][:3] + '</b>')	
-					ctx.show_layout(p_layout)
-					ctx.translate(20, 0)
-					p_layout.set_markup('<b>' +weather[5]["day"][:3] + '</b>')
-					ctx.show_layout(p_layout)
-					ctx.translate(20, 0)
-					p_layout.set_markup('<b>' +weather[6]["day"][:3] + '</b>')	
-					ctx.show_layout(p_layout)
+					ctx.translate(14, 60)
+					self.theme.render(ctx,'day-bg')					
+					#self.theme['day-bg.svg'].render_cairo(ctx)   ###render the days background
+					#print self.theme.path
+					self.draw_text(ctx,'<b>' +weather[1]["day"][:3] + '</b>', 0,0, self.font.split(' ')[0], 6, self.width,pango.ALIGN_LEFT)
+
+				#	p_layout.set_markup('<b>' +weather[1]["day"][:3] + '</b>')						
+				#	ctx.show_layout(p_layout)
+					ctx.translate(24, 0)
+					self.draw_text(ctx,'<b>' +weather[2]["day"][:3] + '</b>', 0,0, self.font.split(' ')[0], 6, self.width,pango.ALIGN_LEFT)
+
+					ctx.translate(24, 0)
+					self.draw_text(ctx,'<b>' +weather[3]["day"][:3] + '</b>', 0,0, self.font.split(' ')[0], 6, self.width,pango.ALIGN_LEFT)
+
+					ctx.translate(24, 0)
+					self.draw_text(ctx,'<b>' +weather[4]["day"][:3] + '</b>', 0,0, self.font.split(' ')[0], 6, self.width,pango.ALIGN_LEFT)
+
+					ctx.translate(24, 0)
+					self.draw_text(ctx,'<b>' +weather[5]["day"][:3] + '</b>', 0,0, self.font.split(' ')[0], 6, self.width,pango.ALIGN_LEFT)
+
+					ctx.translate(24, 0)
+					self.draw_text(ctx,'<b>' +weather[6]["day"][:3] + '</b>', 0,0, self.font.split(' ')[0], 6, self.width,pango.ALIGN_LEFT)
+
 
 					ctx.restore()	
 
@@ -478,108 +463,57 @@ class ClearWeatherScreenlet(screenlets.Screenlet):
 		
 
 					ctx.save()
-					ctx.translate(10, 72)
-					ctx.scale(.2, .2)
-					self.theme.render(ctx,self.get_icon(int(weather[1]["nighticon"]))  )				
-					ctx.translate(98,0)
-					self.theme.render(ctx,   self.get_icon(int(weather[2]["dayicon"])) )	
-					ctx.translate(98,0)
-					self.theme.render(ctx,   self.get_icon(int(weather[3]["dayicon"]))  )	
-					
-
-				
-					ctx.translate(98, 0)
-			
-					self.theme.render(ctx,   self.get_icon(int(weather[4]["dayicon"]))  )				
-					ctx.translate(98,0)
-					self.theme.render(ctx,   self.get_icon(int(weather[5]["dayicon"]))  )	
-					ctx.translate(98,0)
-					self.theme.render(ctx,   self.get_icon(int(weather[6]["dayicon"]))  )	
+					ctx.translate(14, 68)
+					self.draw_scaled_image(ctx,0,0,self.theme.path + '/' +self.get_icon(int(weather[1]["nighticon"]))+ '.png',22,22)
+					ctx.translate(24,0)
+					self.draw_scaled_image(ctx,0,0,self.theme.path + '/' +self.get_icon(int(weather[2]["dayicon"]))+ '.png',22,22)
+					ctx.translate(24,0)
+					self.draw_scaled_image(ctx,0,0,self.theme.path + '/' +self.get_icon(int(weather[3]["dayicon"]))+ '.png',22,22)
+					ctx.translate(24, 0)
+					self.draw_scaled_image(ctx,0,0,self.theme.path + '/' +self.get_icon(int(weather[4]["dayicon"]))+ '.png',22,22)
+					ctx.translate(24,0)
+					self.draw_scaled_image(ctx,0,0,self.theme.path + '/' +self.get_icon(int(weather[5]["dayicon"]))+ '.png',22,22)
 					ctx.restore()						
-					
-
-					p_layout = ctx.create_layout()
-					p_fdesc = pango.FontDescription()
-					p_fdesc.set_family_static("Monospace")
-					p_fdesc.set_size(int(5 * pango.SCALE))
-					p_fdesc.set_weight(300)    ###note:: this font needs to be set only once for the next few 
-					p_fdesc.set_style(pango.STYLE_NORMAL)  #things we need to do, so I'll do it here.
-					p_layout.set_font_description(p_fdesc)	
-		
+	
 					if self.show_daytemp == True:
-						ctx.save()
-						ctx.set_source_rgba(0, 0, 0, 1)
-						ctx.translate(18,76)
-						p_layout.set_markup('<b>' + weather[1]["high"]+degree+'</b>\n'+ weather[1]["low"]+degree)					
-						ctx.show_layout(p_layout)   ##day1's temps
-					
-					
-						ctx.restore()
-		
-						ctx.save()
-						ctx.set_source_rgba(0, 0, 0, 1)
-						ctx.translate(37, 76)
-						p_layout.set_markup('<b>' + weather[2]["high"]+degree+'</b>\n'+ weather[2]["low"]+degree)					
-						ctx.show_layout(p_layout)
-					
-						ctx.restore()
+						ctx.save()	
+						
+						ctx.translate(16,90)
+						self.draw_text(ctx,'<b>' + weather[1]["high"]+degree+'</b>'+ weather[1]["low"]+degree, 0,0, self.font.split(' ')[0], 4, self.width,pango.ALIGN_LEFT)
+						ctx.translate(24, 0)
+						self.draw_text(ctx,'<b>' + weather[2]["high"]+degree+'</b>'+ weather[2]["low"]+degree, 0,0, self.font.split(' ')[0], 4, self.width,pango.ALIGN_LEFT)
+						ctx.translate(24,0)
+						self.draw_text(ctx,'<b>' + weather[3]["high"]+degree+'</b>'+ weather[3]["low"]+degree, 0,0, self.font.split(' ')[0], 4, self.width,pango.ALIGN_LEFT)
+						ctx.translate(24,0)
+						self.draw_text(ctx,'<b>' + weather[4]["high"]+degree+'</b>'+ weather[4]["low"]+degree, 0,0, self.font.split(' ')[0], 4, self.width,pango.ALIGN_LEFT)	
+						ctx.translate(24,0)
+						self.draw_text(ctx,'<b>' + weather[5]["high"]+degree+'</b>'+ weather[5]["low"]+degree, 0,0, self.font.split(' ')[0], 4, self.width,pango.ALIGN_LEFT)
 
-						ctx.save()
-						ctx.set_source_rgba(0, 0, 0, 1)
-						ctx.translate(57, 76)
-						p_layout.set_markup('<b>' + weather[3]["high"]+degree+'</b>\n'+ weather[3]["low"]+degree)					
-						ctx.show_layout(p_layout)
 					
 						ctx.restore()
-
-						ctx.save()
-						ctx.set_source_rgba(0, 0, 0, 1)
-						ctx.translate(76, 76)
-						p_layout.set_markup('<b>' + weather[4]["high"]+degree+'</b>\n'+ weather[4]["low"]+degree)					
-						ctx.show_layout(p_layout)
-					
-						ctx.restore()
-
-						ctx.save()
-						ctx.set_source_rgba(0, 0, 0, 1)
-						ctx.translate(96, 76)
-						p_layout.set_markup('<b>' + weather[5]["high"]+degree+'</b>\n'+ weather[5]["low"]+degree)					
-						ctx.show_layout(p_layout)
-					
-						ctx.restore()
-
-						ctx.save()
-						ctx.set_source_rgba(0, 0, 0, 1)
-						ctx.translate(116, 76)
-						p_layout.set_markup('<b>' + weather[6]["high"]+degree+'</b>\n'+ weather[6]["low"]+degree)					
-						ctx.show_layout(p_layout)
-
-						ctx.restore()
-						ctx.save()
 			
+						
+			
+				self.draw_text(ctx,'<b>' + weather[1]["high"]+degree+'</b>', 68, 28, self.font.split(' ')[0], 5, self.width,pango.ALIGN_LEFT)
+
+
+				self.draw_text(ctx,'<b>' + weather[1]["low"]+degree+'</b>', 68, 34, self.font.split(' ')[0], 5, self.width,pango.ALIGN_LEFT)
 
-				p_layout2 = ctx.create_layout()
-				p_fdesc = pango.FontDescription()
-				p_fdesc.set_family_static("Sans")
-				p_fdesc.set_size(5 * pango.SCALE)
-				p_fdesc.set_weight(300)    ###note:: this font needs to be set only once for the next few 
-				p_fdesc.set_style(pango.STYLE_NORMAL)  #things we need to do, so I'll do it here.
-				p_layout2.set_font_description(p_fdesc)	
-				ctx.translate(68, 28)
-				p_layout2.set_markup('<b>' + weather[1]["high"]+degree+'</b>')					
-				ctx.show_layout(p_layout2)   ##day1's temps
-				ctx.translate(0, 6)
-				p_layout2.set_markup('<b>' + weather[1]["low"]+degree+'</b>')
-				ctx.show_layout(p_layout2)
 				if weather[1]["dayppcp"] <> '0':
-					ctx.translate(0, 6)
-					p_layout2.set_markup('<i>' + weather[1]["dayppcp"]+'%</i>')
-					ctx.show_layout(p_layout2)
+					self.draw_text(ctx,'<i>' + weather[1]["dayppcp"]+'%</i>', 68, 40, self.font.split(' ')[0], 5, self.width,pango.ALIGN_LEFT)
+					
 				
 		
 		
 					
+	def on_mouse_down(self,event):
+		if event.button == 1:
+			x = event.x / self.scale
+			y = event.y / self.scale
 
+		
+			if y >= 75 and x <= 132 and x >= 110:
+				os.system('xdg-open weather.com')
 
 	def on_draw_shape(self,ctx):
 		if self.theme:
